@@ -46,7 +46,14 @@ class RosRule(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosRule.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RosRuleProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: builtins.bool,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -62,7 +69,9 @@ class RosRule(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosRule._render_properties)
+            def stub(props: typing.Mapping[builtins.str, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -109,7 +118,9 @@ class RosRule(
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRule, "enable_resource_property_constraint").fset)
+            def stub(value: builtins.bool) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
@@ -127,7 +138,11 @@ class RosRule(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRule, "event_bus_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventBusName", value)
 
@@ -147,7 +162,11 @@ class RosRule(
         value: typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRule, "filter_pattern").fset)
+            def stub(
+                value: typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "filterPattern", value)
 
@@ -165,7 +184,11 @@ class RosRule(
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRule, "rule_name").fset)
+            def stub(
+                value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ruleName", value)
 
@@ -185,7 +208,11 @@ class RosRule(
         value: typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[ros_cdk_core.IResolvable, "RosRule.TargetsProperty"]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRule, "targets").fset)
+            def stub(
+                value: typing.Union[ros_cdk_core.IResolvable, typing.List[typing.Union[ros_cdk_core.IResolvable, "RosRule.TargetsProperty"]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targets", value)
 
@@ -205,7 +232,11 @@ class RosRule(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRule, "description").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -229,7 +260,11 @@ class RosRule(
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(RosRule, "status").fset)
+            def stub(
+                value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
@@ -259,7 +294,15 @@ class RosRule(
             :param template: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosRule.ParamListProperty.__init__)
+                def stub(
+                    *,
+                    form: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    resource_key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    template: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument form", value=form, expected_type=type_hints["form"])
                 check_type(argname="argument resource_key", value=resource_key, expected_type=type_hints["resource_key"])
                 check_type(argname="argument value", value=value, expected_type=type_hints["value"])
@@ -349,7 +392,16 @@ class RosRule(
             :param push_retry_strategy: 
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(RosRule.TargetsProperty.__init__)
+                def stub(
+                    *,
+                    endpoint: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    id: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    param_list: typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union["RosRule.ParamListProperty", typing.Dict[str, typing.Any]]]]],
+                    type: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                    push_retry_strategy: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                ) -> None:
+                    ...
+                type_hints = typing.get_type_hints(stub)
                 check_type(argname="argument endpoint", value=endpoint, expected_type=type_hints["endpoint"])
                 check_type(argname="argument id", value=id, expected_type=type_hints["id"])
                 check_type(argname="argument param_list", value=param_list, expected_type=type_hints["param_list"])
@@ -457,7 +509,17 @@ class RosRuleProps:
         :param status: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RosRuleProps.__init__)
+            def stub(
+                *,
+                event_bus_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                filter_pattern: typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]],
+                rule_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                targets: typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosRule.TargetsProperty, typing.Dict[str, typing.Any]]]]],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                status: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument event_bus_name", value=event_bus_name, expected_type=type_hints["event_bus_name"])
             check_type(argname="argument filter_pattern", value=filter_pattern, expected_type=type_hints["filter_pattern"])
             check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
@@ -577,7 +639,14 @@ class Rule(
         :param enable_resource_property_constraint: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Rule.__init__)
+            def stub(
+                scope: ros_cdk_core.Construct,
+                id: builtins.str,
+                props: typing.Union["RuleProps", typing.Dict[str, typing.Any]],
+                enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
@@ -639,7 +708,17 @@ class RuleProps:
         :param status: Property status: The status of the event rule. Valid values: ENABLE: The event rule is enabled. It is the default state of the event rule. DISABLE: The event rule is disabled.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RuleProps.__init__)
+            def stub(
+                *,
+                event_bus_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                filter_pattern: typing.Union[ros_cdk_core.IResolvable, typing.Mapping[builtins.str, typing.Any]],
+                rule_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+                targets: typing.Union[ros_cdk_core.IResolvable, typing.Sequence[typing.Union[ros_cdk_core.IResolvable, typing.Union[RosRule.TargetsProperty, typing.Dict[str, typing.Any]]]]],
+                description: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+                status: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument event_bus_name", value=event_bus_name, expected_type=type_hints["event_bus_name"])
             check_type(argname="argument filter_pattern", value=filter_pattern, expected_type=type_hints["filter_pattern"])
             check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
